#[repr(u8)]pub enum Opcode {
Show 34 variants
Get = 0,
Set = 1,
Add = 2,
Replace = 3,
Delete = 4,
Increment = 5,
Decrement = 6,
Quit = 7,
Flush = 8,
GetQ = 9,
Noop = 10,
Version = 11,
GetK = 12,
GetKQ = 13,
Append = 14,
Prepend = 15,
SetQ = 17,
AddQ = 18,
ReplaceQ = 19,
DeleteQ = 20,
IncrementQ = 21,
DecrementQ = 22,
QuitQ = 23,
FlushQ = 24,
AppendQ = 25,
PrependQ = 26,
Stat = 16,
Verbosity = 27,
Touch = 28,
GAT = 29,
GATQ = 30,
SaslListMechs = 32,
SaslAuth = 33,
SaslStep = 34,
}Expand description
Memcached binary-protocol opcode.
Covers the full set of opcodes supported by the RedCouch bridge, including quiet variants, SASL auth, stats, and touch/GAT commands.
Variants
Get = 0
Set = 1
Add = 2
Replace = 3
Delete = 4
Increment = 5
Decrement = 6
Quit = 7
Flush = 8
GetQ = 9
Noop = 10
Version = 11
GetK = 12
GetKQ = 13
Append = 14
Prepend = 15
SetQ = 17
AddQ = 18
ReplaceQ = 19
DeleteQ = 20
IncrementQ = 21
DecrementQ = 22
QuitQ = 23
FlushQ = 24
AppendQ = 25
PrependQ = 26
Stat = 16
Verbosity = 27
Touch = 28
GAT = 29
GATQ = 30
SaslListMechs = 32
SaslAuth = 33
SaslStep = 34
Implementations
Sourceimpl Opcode
impl Opcode
Sourcepub fn parse(b: u8) -> Option<Self>
pub fn parse(b: u8) -> Option<Self>
Parse a raw opcode byte into an Opcode, returning None for
unrecognised values.
Sourcepub fn is_quiet(self) -> bool
pub fn is_quiet(self) -> bool
Returns true for quiet variants that suppress certain responses.
GET quiet variants suppress miss responses; mutation quiet variants
suppress success responses (errors are still sent).
Sourcepub fn includes_key(self) -> bool
pub fn includes_key(self) -> bool
Returns true for GETK/GETKQ/GAT/GATQ which echo the key in the response.