write_error_for_raw_opcode

Function write_error_for_raw_opcode 

pub fn write_error_for_raw_opcode(
    w: &mut impl Write,
    opcode_byte: u8,
    status: u16,
    opaque: u32,
    body: &[u8],
) -> Result<()>
Write an error response for an unknown or malformed opcode, using the raw opcode byte from the wire.